==> appconsent_classic-0.0.1.tar.gz: android/src/main/kotlin/io/sfbx/appconsent_classic/AppconsentClassicPlugin.kt <==
package io.sfbx.appconsent_classic

import android.app.Activity
import android.content.Context
import androidx.annotation.NonNull

import io.flutter.embedding.engine.plugins.FlutterPlugin
import io.flutter.embedding.engine.plugins.activity.ActivityAware
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.MethodChannel.MethodCallHandler
import io.flutter.plugin.common.MethodChannel.Result

import com.sfbx.appconsent.ui.AppConsentUI

/** AppconsentClassicPlugin */
class AppconsentClassicPlugin: FlutterPlugin, MethodCallHandler, ActivityAware  {
  /// The MethodChannel that will the communication between Flutter and native Android
  ///
  /// This local reference serves to register the plugin with the Flutter Engine and unregister it
  /// when the Flutter Engine is detached from the Activity
  private lateinit var channel : MethodChannel
  private lateinit var context: Context
  private lateinit var activity: Activity

  var ackit : AppConsentUI? = null

  override fun onDetachedFromActivity() {
    TODO("Not yet implemented")
  }

  override fun onReattachedToActivityForConfigChanges(binding: ActivityPluginBinding) {
    TODO("Not yet implemented")
  }

  override fun onAttachedToActivity(binding: ActivityPluginBinding) {
    activity = binding.activity;
  }

  override fun onDetachedFromActivityForConfigChanges() {
    TODO("Not yet implemented")
  }

  override fun onAttachedToEngine(@NonNull flutterPluginBinding: FlutterPlugin.FlutterPluginBinding) {
    channel = MethodChannel(flutterPluginBinding.binaryMessenger, "appconsent_classic")
    channel.setMethodCallHandler(this)
    context = flutterPluginBinding.applicationContext
  }

  override fun onMethodCall(@NonNull call: MethodCall, @NonNull result: Result) {
    when (call.method) {
      "setup" -> setup(call, result)
      "presentNotice" -> presentNotice(call, result)
      "clearConsent" -> clearConsent(result)
      "checkForUpdate" -> result.notImplemented()
      "isGDPRCountry" -> isGDPRCountry(result)
      "consentGiven" -> consentGiven(result)
      else -> {
        result.notImplemented()
      }
    }
  }

  override fun onDetachedFromEngine(@NonNull binding: FlutterPlugin.FlutterPluginBinding) {
    channel.setMethodCallHandler(null)
  }

  private fun setup(call: MethodCall, result: Result) {
    val appKey: String = call.argument("appKey") ?: ""
    val forceApplyGDPR: Boolean = call.argument("forceApplyGDPR") ?: true
    ackit = AppConsentUI(context = activity, appKey = appKey, forceApplyGDPR = forceApplyGDPR)
    result.success(null)
  }

  private fun presentNotice(call: MethodCall, result: Result) {
    val force: Boolean = call.argument("force") ?: false
    ackit!!.presentNotice(force)
    result.success(null)
  }

  private fun clearConsent(result: Result) {
    ackit!!.clearConsent()
    result.success(null)
  }

  private fun isGDPRCountry(result: Result) {
    var isGDPRCountry = ackit!!.isSubjectToGDPR()
    result.success(isGDPRCountry)
  }

  private fun consentGiven(result: Result) {
    var consentGiven = ackit!!.consentGiven()
    result.success(consentGiven)
  }
}

==> appconsent_classic-0.1.0.tar.gz: android/src/main/kotlin/io/sfbx/appconsent_classic/AppconsentClassicPlugin.kt <==
package io.sfbx.appconsent_classic

import android.app.Activity
import android.content.Context
import androidx.annotation.NonNull

import io.flutter.embedding.engine.plugins.FlutterPlugin
import io.flutter.embedding.engine.plugins.activity.ActivityAware
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.MethodChannel.MethodCallHandler
import io.flutter.plugin.common.MethodChannel.Result

import com.sfbx.appconsent.ui.AppConsentUI
import com.sfbx.appconsent.core.model.ConsentableType

/** AppconsentClassicPlugin */
class AppconsentClassicPlugin: FlutterPlugin, MethodCallHandler, ActivityAware  {
  /// The MethodChannel that will handle the communication between Flutter and native Android
  ///
  /// This local reference serves to register the plugin with the Flutter Engine and unregister it
  /// when the Flutter Engine is detached from the Activity
  private lateinit var channel : MethodChannel
  private lateinit var context: Context
  private lateinit var activity: Activity

  var ackit : AppConsentUI? = null

  override fun onDetachedFromActivity() {
    TODO("Not yet implemented")
  }

  override fun onReattachedToActivityForConfigChanges(binding: ActivityPluginBinding) {
    TODO("Not yet implemented")
  }

  override fun onAttachedToActivity(binding: ActivityPluginBinding) {
    activity = binding.activity;
  }

  override fun onDetachedFromActivityForConfigChanges() {
    TODO("Not yet implemented")
  }

  override fun onAttachedToEngine(@NonNull flutterPluginBinding: FlutterPlugin.FlutterPluginBinding) {
    channel = MethodChannel(flutterPluginBinding.binaryMessenger, "appconsent_classic")
    channel.setMethodCallHandler(this)
    context = flutterPluginBinding.applicationContext
  }

  override fun onMethodCall(@NonNull call: MethodCall, @NonNull result: Result) {
    when (call.method) {
      "setup" -> setup(call, result)
      "presentNotice" -> presentNotice(call, result)
      "clearConsent" -> clearConsent(result)
      "checkForUpdate" -> checkForUpdate(result)
      "isSubjectToGDPR" -> isSubjectToGDPR(result)
      "consentGiven" -> consentGiven(result)
      "consentableAllowed" -> consentableAllowed(call, result)
      else -> {
        result.notImplemented()
      }
    }
  }

  override fun onDetachedFromEngine(@NonNull binding: FlutterPlugin.FlutterPluginBinding) {
    channel.setMethodCallHandler(null)
  }

  private fun setup(call: MethodCall, result: Result) {
    val appKey: String = call.argument("appKey") ?: ""
    val forceApplyGDPR: Boolean = call.argument("forceApplyGDPR") ?: true
    ackit = AppConsentUI(context = activity, appKey = appKey, forceApplyGDPR = forceApplyGDPR)
    result.success(null)
  }

  private fun presentNotice(call: MethodCall, result: Result) {
    val force: Boolean = call.argument("force") ?: false
    ackit!!.presentNotice(force)
    result.success(null)
  }

  private fun clearConsent(result: Result) {
    ackit!!.clearConsent()
    result.success(null)
  }

  private fun checkForUpdate(result: Result) {
    ackit!!.checkForUpdate(onResult = {
        result.success(it)
      },
      error = {
        result.success(false)
      })
  }

  private fun isSubjectToGDPR(result: Result) {
    var isSubjectToGDPR = ackit!!.isSubjectToGDPR()
    result.success(isSubjectToGDPR)
  }

  private fun consentGiven(result: Result) {
    var consentGiven = ackit!!.consentGiven()
    result.success(consentGiven)
  }

  private fun consentableAllowed(call: MethodCall, result: Result) {
    val iabId: Int = call.argument("iabId") ?: 0
    val type: Int = call.argument("consentableType") ?: 0
    val consentableType: ConsentableType = when (type) {
      0 -> ConsentableType.PURPOSE
      1 -> ConsentableType.FEATURE
      2 -> ConsentableType.SPECIAL_FEATURE
      3 -> ConsentableType.SPECIAL_PURPOSE
      else -> ConsentableType.UNKNOWN
    }
    val isAllowed = ackit!!.consentableAllowed(iabId, consentableType)
    result.success(isAllowed)
  }
}
